@@ -2,13 +2,9 @@ use strict;
 
 package HTML::Restrict;
 {
-  $HTML::Restrict::VERSION = '2.1.8';
+  $HTML::Restrict::VERSION = '2.1.9';
 }
 
-use namespace::autoclean;
-
-use Moo 1.002000;
-
 use Carp qw( croak );
 use Data::Dump qw( dump );
 use HTML::Parser;
@@ -18,6 +14,9 @@ use Scalar::Util qw( reftype weaken );
 use Sub::Quote 'quote_sub';
 use URI;
 
+use Moo 1.002000;
+use namespace::clean;
+
 has 'allow_comments' => (
     is      => 'rw',
     isa     => Bool,
@@ -331,7 +330,7 @@ HTML::Restrict - Strip unwanted HTML tags and attributes
 
 =head1 VERSION
 
-version 2.1.8
+version 2.1.9
 
 =head1 SYNOPSIS
 
